<?php

namespace Fegerer\AppTest\Http\Controllers;

use App\Http\Controllers\UserController as UserController;
use Form;
use Fegerer\AppTest\Http\Requests\ActiontypeUserRequest;
use Fegerer\AppTest\Interfaces\ActiontypeRepositoryInterface;
use Fegerer\AppTest\Models\Actiontype;

class ActiontypeUserController extends UserController
{
    /**
     * Initialize actiontype controller.
     *
     * @param type ActiontypeRepositoryInterface $actiontype
     *
     * @return type
     */
    public function __construct(ActiontypeRepositoryInterface $actiontype)
    {
        $this->repository = $actiontype;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(ActiontypeUserRequest $request)
    {
        $this->repository->pushCriteria(new \Lavalite\AppTest\Repositories\Criteria\ActiontypeUserCriteria());
        $actiontypes = $this->repository->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();

        $this->theme->prependTitle(trans('app_test::actiontype.names').' :: ');

        return $this->theme->of('app_test::user.actiontype.index', compact('actiontypes'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param Actiontype $actiontype
     *
     * @return Response
     */
    public function show(ActiontypeUserRequest $request, Actiontype $actiontype)
    {
        Form::populate($actiontype);

        return $this->theme->of('app_test::user.actiontype.show', compact('actiontype'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ActiontypeUserRequest $request)
    {

        $actiontype = $this->repository->newInstance([]);
        Form::populate($actiontype);

        return $this->theme->of('app_test::user.actiontype.create', compact('actiontype'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ActiontypeUserRequest $request)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $actiontype = $this->repository->create($attributes);

            $this->responseCode = 201;
            $this->responseMessage = trans('messages.success.created', ['Module' => trans('app_test::actiontype.name')]);
            $this->responseRedirect = trans_url('/user/app_test/actiontype');
            return $this -> respond($request);
        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param Actiontype $actiontype
     *
     * @return Response
     */
    public function edit(ActiontypeUserRequest $request, Actiontype $actiontype)
    {

        Form::populate($actiontype);

        return $this->theme->of('app_test::user.actiontype.edit', compact('actiontype'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param Actiontype $actiontype
     *
     * @return Response
     */
    public function update(ActiontypeUserRequest $request, Actiontype $actiontype)
    {
        try {
            $this->repository->update($request->all(), $actiontype->getRouteKey());
            $this->responseCode = 204;
            $this->responseMessage = trans('messages.success.updated', ['Module' => trans('app_test::actiontype.name')]);
            $this->responseRedirect = trans_url('/user/app_test/actiontype');
            return $this -> respond($request);
        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(ActiontypeUserRequest $request, Actiontype $actiontype)
    {
        try {
            $this->repository->delete($actiontype->getRouteKey());
            $this->responseCode = 204;
            $this->responseMessage = trans('messages.success.deleted', ['Module' => trans('app_test::actiontype.name')]);
            $this->responseRedirect = trans_url('/user/app_test/actiontype');
            return $this -> respond($request);
        } catch (Exception $e) {

            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);

        }
    }
}
