<?php

namespace Fegerer\AppTest\Policies;

use App\User;
use Illuminate\Auth\Access\HandlesAuthorization;
use Fegerer\AppTest\Models\Actiontype;

class ActiontypePolicy
{
    use HandlesAuthorization;

    /**
     * Determine if the given user can view the actiontype.
     *
     * @param User $user
     * @param Actiontype $actiontype
     *
     * @return bool
     */
    public function view(User $user, Actiontype $actiontype)
    {
        if ($user->canDo('app_test.actiontype.view') && $user->is('admin')) {
            return true;
        }

        return $user->id === $actiontype->user_id;
    }

    /**
     * Determine if the given user can create a actiontype.
     *
     * @param User $user
     * @param Actiontype $actiontype
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('app_test.actiontype.create');
    }

    /**
     * Determine if the given user can update the given actiontype.
     *
     * @param User $user
     * @param Actiontype $actiontype
     *
     * @return bool
     */
    public function update(User $user, Actiontype $actiontype)
    {
        if ($user->canDo('app_test.actiontype.update') && $user->is('admin')) {
            return true;
        }

        return $user->id === $actiontype->user_id;
    }

    /**
     * Determine if the given user can delete the given actiontype.
     *
     * @param User $user
     * @param Actiontype $actiontype
     *
     * @return bool
     */
    public function delete(User $user, Actiontype $actiontype)
    {
        if ($user->canDo('app_test.actiontype.delete') && $user->is('admin')) {
            return true;
        }

        return $user->id === $actiontype->user_id;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
