<?php

namespace Fegerer\AppTest\Providers;

use Illuminate\Support\ServiceProvider;

class AppTestServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../../../resources/views', 'app_test');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../../../resources/lang', 'app_test');

        // Call pblish redources function
        $this->publishResources();

        include __DIR__ . '/../Http/routes.php';
    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('app_test', function ($app) {
            return $this->app->make('Fegerer\AppTest\AppTest');
        });

// Bind Action to repository
        $this->app->bind(
            \Fegerer\AppTest\Interfaces\ActionRepositoryInterface::class,
            \Fegerer\AppTest\Repositories\Eloquent\ActionRepository::class
        );
        // Bind Actiontypecategory to repository
        $this->app->bind(
            \Fegerer\AppTest\Interfaces\ActiontypecategoryRepositoryInterface::class,
            \Fegerer\AppTest\Repositories\Eloquent\ActiontypecategoryRepository::class
        );
        // Bind Actiontype to repository
        $this->app->bind(
            \Fegerer\AppTest\Interfaces\ActiontypeRepositoryInterface::class,
            \Fegerer\AppTest\Repositories\Eloquent\ActiontypeRepository::class
        );

        $this->app->register(\Fegerer\AppTest\Providers\AuthServiceProvider::class);
        $this->app->register(\Fegerer\AppTest\Providers\EventServiceProvider::class);
        $this->app->register(\Fegerer\AppTest\Providers\RouteServiceProvider::class);
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['app_test'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../../../config/config.php' => config_path('package/app_test.php')], 'config');

        // Publish public view
        $this->publishes([__DIR__ . '/../../../../resources/views/public'  => base_path('resources/views/vendor/app_test/public')], 'view-public');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../../../resources/views/admin' => base_path('resources/views/vendor/app_test/admin')], 'view-admin');

        // Publish language files
        $this->publishes([__DIR__ . '/../../../../resources/lang' => base_path('resources/lang/vendor/app_test')], 'lang');

        // Publish migrations
        $this->publishes([__DIR__ . '/../../../../database/migrations/' => base_path('database/migrations')], 'migrations');

        // Publish seeds
        $this->publishes([__DIR__ . '/../../../../database/seeds/' => base_path('database/seeds')], 'seeds');
    }
}
